pub struct SystemCapabilities {
pub product: String,
pub provisioning: bool,
pub login_readiness: bool,
pub federated_project_auth: bool,
}Expand description
Bounded capabilities returned after Control operator authentication.
Fields
product: StringProduct identifier for this Control endpoint.
provisioning: boolWhether Project, Application, key, and provider provisioning is implemented.
login_readiness: boolWhether Runtime configuration and signing-key publication readiness is implemented.
federated_project_auth: boolWhether end-user federated login, handoff, and session operations are implemented.