pub struct EmailProofResponse {
pub completed: bool,
pub redirect_url: Option<String>,
pub application_type: Option<HostedApplicationType>,
}Fields
completed: boolredirect_url: Option<String>application_type: Option<HostedApplicationType>Trusted type of the stored Application that owns this exact interaction. Present only on successful completion and used by Hosted UI to validate the final navigation scheme.